OC.L10N.register(
    "groupfolders",
    {
    "Denied (Inherited permission)" : "Denied (Inherited permission)",
    "Allowed (Inherited permission)" : "Allowed (Inherited permission)",
    "Denied" : "Denied",
    "Allowed" : "Allowed",
    "Access denied" : "Access denied",
    "Access allowed" : "Access allowed",
    "Inherit permission" : "Inherit permission",
    "Deny" : "Deny",
    "Allow" : "Allow",
    "Group" : "Group",
    "Read" : "Read",
    "Write" : "Write",
    "Create" : "Create",
    "Delete" : "Delete",
    "Share" : "Share",
    "You" : "You",
    "Remove access rule" : "Remove access rule",
    "Select a user or group" : "Select a user or group",
    "Add group" : "Add group",
    "Default" : "Default",
    "Unlimited" : "Unlimited",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone",
    "Delete \"{folderName}\"?" : "Delete \"{folderName}\"?",
    "Folder name" : "Folder name",
    "Quota" : "Quota",
    "Advanced Permissions" : "Advanced Permissions",
    "Previous" : "Previous",
    "Next" : "Next",
    "User" : "User",
    "Unknown" : "Unknown",
    "None" : "None",
    "{size} used" : "{size} used",
    "Unset" : "Unset"
},
"nplurals=2; plural=(n!=1);");
